# All Math Ops

This is a simple Python package that provides basic math operations.
Install:
$ pip install demo24_math_ops

Usage:
from demo24_math_ops import addition_module, subtraction_module, multiplication_module, division_module
